@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.010007'; # VERSION
+our $VERSION = '0.010008'; # VERSION
 
 1;
 
@@ -21,7 +21,7 @@ Business::CyberSource - Perl interface to the CyberSource Simple Order SOAP API
 
 =head1 VERSION
 
-version 0.010007
+version 0.010008
 
 =head1 DESCRIPTION
 
@@ -129,6 +129,8 @@ someone is using C<die> on a string.
 				purchase_totals => {
 					currency => 'USD',
 					total    => 5.00,
+					discount => 0.03, # optional and may depend on processor
+					duty     => 0.01, # optional and may depend on processor
 				},
 				card => {
 					account_number => '4111111111111111',
@@ -180,6 +182,8 @@ someone is using C<die> on a string.
 				},
 				purchase_totals => {
 					total    => $auth_response->auth->amount,
+					discount => '0.05', # optional and may depend on processor
+					duty     => '0.01', # optional and may depend on processor
 					currency => $auth_response->purchase_totals->currency,
 				},
 			});
@@ -254,7 +258,7 @@ funding further development.
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/xenoterracide/business-cybersource/issues
+https://github.com/hostgator/business-cybersource/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -262,12 +266,16 @@ feature.
 
 =head1 CONTRIBUTORS
 
-=for stopwords Carl Carstenson Lantz Jonathan William Taylor Robert Stone
+=for stopwords bvoskr Carl Carstenson Lantz dmaestro irinatodeva Jonathan William Taylor Robert Stone Rummy
 
 =over 4
 
 =item *
 
+bvoskr <boris.voskresenskiy@endurance.com>
+
+=item *
+
 Carl Carstenson <ccarstenson@hostgator.com>
 
 =item *
@@ -276,12 +284,28 @@ Carl Lantz <carl.lantz@endurance.com>
 
 =item *
 
+dmaestro <dmaestro@users.noreply.github.com>
+
+=item *
+
+irinatodeva <irinatodeva@users.noreply.github.com>
+
+=item *
+
+Jonathan William Taylor <elderling@gmail.com>
+
+=item *
+
 Jonathan William Taylor <jonathan.taylor@endurance.com>
 
 =item *
 
 Robert Stone <robertstone@hostgator.com>
 
+=item *
+
+Rummy <cerealbh@gmail.com>
+
 =back
 
 =head1 AUTHOR
@@ -290,7 +314,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Caleb Cushing <xenoterracide@gmail.com>.
+This software is Copyright (c) 2017 by Caleb Cushing <xenoterracide@gmail.com>.
 
 This is free software, licensed under:
 
