@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.010007'; # VERSION
+our $VERSION = '0.010008'; # VERSION
 
 use MooseX::AbstractFactory;
 implementation_class_via sub { 'Business::CyberSource::Request::' . shift };
@@ -24,7 +24,7 @@ Business::CyberSource::Factory::Request - CyberSource Request Factory Module
 
 =head1 VERSION
 
-version 0.010007
+version 0.010008
 
 =head1 SYNOPSIS
 
@@ -48,6 +48,8 @@ version 0.010007
 			purchase_totals => {
 				currency => 'USD',
 				total    => 5.00,
+				discount => 0.10, # optional
+				duty     => 0.03, # optional
 			},
 			card => {
 				account_number => '4111111111111111',
@@ -98,7 +100,7 @@ C<Business::CyberSource::Request::>.
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/xenoterracide/business-cybersource/issues
+https://github.com/hostgator/business-cybersource/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -110,7 +112,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Caleb Cushing <xenoterracide@gmail.com>.
+This software is Copyright (c) 2017 by Caleb Cushing <xenoterracide@gmail.com>.
 
 This is free software, licensed under:
 
