@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.010007'; # VERSION
+our $VERSION = '0.010008'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::Request';
@@ -54,7 +54,7 @@ Business::CyberSource::Request::Authorization - CyberSource Authorization Reques
 
 =head1 VERSION
 
-version 0.010007
+version 0.010008
 
 =head1 SYNOPSIS
 
@@ -75,6 +75,8 @@ version 0.010007
 		purchase_totals => {
 			currency => 'USD',
 			total    => 5.00,
+			discount => 0.50, # optional
+			duty     => 0.03, # optional
 		},
 		card => {
 			account_number => '4111111111111111',
@@ -83,6 +85,15 @@ version 0.010007
 				year  => 2025,
 			},
 		},
+		# optional:
+		ship_to => {
+			country     => 'US',
+			postal_code => '78701',
+			city        => 'Austin',
+			state       => 'TX',
+			street1     => '306 E 6th',
+			street2     => 'Dizzy Rooster',
+		},
 	});
 
 =head1 DESCRIPTION
@@ -122,6 +133,10 @@ Merchant Reference Code
 
 L<Business::CyberSource::RequestPart::BillTo>
 
+=head2 ship_to
+
+L<Business::CyberSource::RequestPart::ShipTo>
+
 =head2 purchase_totals
 
 L<Business::CyberSource::RequestPart::PurchaseTotals>
@@ -139,7 +154,7 @@ L<Business::CyberSource::RequestPart::BusinessRules>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/xenoterracide/business-cybersource/issues
+https://github.com/hostgator/business-cybersource/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -151,7 +166,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Caleb Cushing <xenoterracide@gmail.com>.
+This software is Copyright (c) 2017 by Caleb Cushing <xenoterracide@gmail.com>.
 
 This is free software, licensed under:
 
