@@ -3,21 +3,21 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.010007'; # VERSION
+our $VERSION = '0.010008'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::Request';
 with qw(
-	Business::CyberSource::Request::Role::DCC
-	Business::CyberSource::Request::Role::TaxService
+  Business::CyberSource::Request::Role::DCC
+  Business::CyberSource::Request::Role::TaxService
 );
 
 use MooseX::Types::CyberSource qw( CaptureService );
 
 has '+service' => (
-	isa         => CaptureService,
-	remote_name => 'ccCaptureService',
-	lazy_build  => 0,
+    isa         => CaptureService,
+    remote_name => 'ccCaptureService',
+    lazy_build  => 0,
 );
 
 __PACKAGE__->meta->make_immutable;
@@ -37,7 +37,7 @@ Business::CyberSource::Request::Capture - CyberSource Capture Request Object
 
 =head1 VERSION
 
-version 0.010007
+version 0.010008
 
 =head1 SYNOPSIS
 
@@ -51,7 +51,29 @@ version 0.010007
 		purchase_totals => {
 			total    => 5.01,  # same amount as in authorization
 			currency => 'USD', # same currency as in authorization
+                        discount => 0.50,  # optional
+                        duty     => 0.07,  # optional
 		},
+		# optional:
+		ship_to => {
+			country     => 'US',
+			postal_code => '78701',
+			city        => 'Austin',
+			state       => 'TX',
+			street1     => '306 E 6th',
+			street2     => 'Dizzy Rooster',
+		},
+        invoice_header => {
+            purchaser_vat_registration_number => 'ATU99999999',
+            user_po => '123456',
+            vat_invoice_reference_number => '1234',
+        },
+        other_tax => {
+            alternate_tax_amount => '00.10',
+            alternate_tax_indicator => 1,
+            vat_tax_amount => '0.10',
+            vat_tax_rate => '0.10',
+        },
 	});
 
 =head1 DESCRIPTION
@@ -73,7 +95,7 @@ L<Business::CyberSource::Request>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/xenoterracide/business-cybersource/issues
+https://github.com/hostgator/business-cybersource/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -85,7 +107,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Caleb Cushing <xenoterracide@gmail.com>.
+This software is Copyright (c) 2017 by Caleb Cushing <xenoterracide@gmail.com>.
 
 This is free software, licensed under:
 
