@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.010007'; # VERSION
+our $VERSION = '0.010008'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::Request';
@@ -12,7 +12,7 @@ with qw(
 	Business::CyberSource::Request::Role::TaxService
 );
 
-use MooseX::Types::CyberSource qw( BillTo Card CreditService);
+use MooseX::Types::CyberSource qw( BillTo Card CreditService );
 
 use Module::Runtime qw( use_module );
 
@@ -59,7 +59,7 @@ Business::CyberSource::Request::Credit - CyberSource Credit Request Object
 
 =head1 VERSION
 
-version 0.010007
+version 0.010008
 
 =head1 SYNOPSIS
 
@@ -79,6 +79,8 @@ version 0.010007
 			},
 			purchase_totals => {
 				total    => 5.00,
+				discount => 0.50, # optional
+				duty     => 0.01, # optional
 				currency => 'USD',
 			},
 			card => {
@@ -88,6 +90,17 @@ version 0.010007
 					year => '2025',
 				},
 			},
+            invoice_header => {
+                purchaser_vat_registration_number => 'ATU99999999',
+                user_po => '123456',
+                vat_invoice_reference_number => '1234',
+            },
+            other_tax => {
+                alternate_tax_amount => '0.10',
+                alternate_tax_indicator => 1,
+                vat_tax_amount => '0.10',
+                vat_tax_rate => '0.10',
+            },
 		});
 
 =head1 DESCRIPTION
@@ -112,7 +125,7 @@ L<Business::CyberSource::Request>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/xenoterracide/business-cybersource/issues
+https://github.com/hostgator/business-cybersource/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -124,7 +137,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Caleb Cushing <xenoterracide@gmail.com>.
+This software is Copyright (c) 2017 by Caleb Cushing <xenoterracide@gmail.com>.
 
 This is free software, licensed under:
 
