@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.010007'; # VERSION
+our $VERSION = '0.010008'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::Request::Credit';
@@ -36,7 +36,7 @@ Business::CyberSource::Request::FollowOnCredit - CyberSource Credit Request Obje
 
 =head1 VERSION
 
-version 0.010007
+version 0.010008
 
 =head1 SYNOPSIS
 
@@ -46,6 +46,8 @@ version 0.010007
 			reference_code => 'merchant reference code',
 			purchase_totals => {
 				total    => 5.00,
+				discount => 0.05,
+				duty     => 0.01,
 				currency => 'USD',
 			},
 			service => {
@@ -64,7 +66,7 @@ L<Business::CyberSource::Request::Credit>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/xenoterracide/business-cybersource/issues
+https://github.com/hostgator/business-cybersource/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -76,7 +78,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Caleb Cushing <xenoterracide@gmail.com>.
+This software is Copyright (c) 2017 by Caleb Cushing <xenoterracide@gmail.com>.
 
 This is free software, licensed under:
 
