@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.010007'; # VERSION
+our $VERSION = '0.010008'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::Request::Authorization';
@@ -38,7 +38,7 @@ Business::CyberSource::Request::Sale - Sale Request Object
 
 =head1 VERSION
 
-version 0.010007
+version 0.010008
 
 =head1 SYNOPSIS
 
@@ -59,6 +59,8 @@ version 0.010007
 			},
 			purchase_totals => {
 				total    => 3000.00,
+				discount => 50.00, # optional
+				duty     => 10.00, # optional
 				currency => 'USD',
 			},
 			card => {
@@ -91,7 +93,7 @@ attribute. It is built for you and cannot be modified.
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/xenoterracide/business-cybersource/issues
+https://github.com/hostgator/business-cybersource/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -103,7 +105,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Caleb Cushing <xenoterracide@gmail.com>.
+This software is Copyright (c) 2017 by Caleb Cushing <xenoterracide@gmail.com>.
 
 This is free software, licensed under:
 
