@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.010007'; # VERSION
+our $VERSION = '0.010008'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::MessagePart';
@@ -76,6 +76,13 @@ has national_tax => (
 	is          => 'rw',
 );
 
+has invoice_number => (
+    isa => NonEmptySimpleStr,
+    remote_name => 'invoiceNumber',
+    is => 'ro',
+    required => 0,
+);
+
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -93,7 +100,7 @@ Business::CyberSource::RequestPart::Item - Item Helper Class
 
 =head1 VERSION
 
-version 0.010007
+version 0.010008
 
 =head1 EXTENDS
 
@@ -153,10 +160,12 @@ The total amount authorized will be 32.40, not 30.00 with 2.40 of tax included.
 
 =head2 national_tax
 
+=head2 invoice_number
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/xenoterracide/business-cybersource/issues
+https://github.com/hostgator/business-cybersource/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -168,7 +177,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Caleb Cushing <xenoterracide@gmail.com>.
+This software is Copyright (c) 2017 by Caleb Cushing <xenoterracide@gmail.com>.
 
 This is free software, licensed under:
 
